@@ -16,7 +16,7 @@
 #	You should have received a copy of the GNU General Public License
 #	along with OpenShot Video Editor.  If not, see <http://www.gnu.org/licenses/>.
 
-import effect
+import effect, copy
 import os, locale, uuid
 import xml.dom.minidom as xml
 import gtk, goocanvas
@@ -57,6 +57,10 @@ class clip:
 		self.file_object = file_object  # the file object that this clip is linked to
 		self.unique_id = str(uuid.uuid1())
 		self.rotation = 0.0
+		self.thumb_location = ""
+		
+		# Update the thumbnail of the clip and the location
+		self.update_thumbnail()
 		
 		# init key-frame dictionary
 		self.keyframes = {"start" : keyframe(0, 100.0, 100.0, 0.0, 0.0, 1.0),
@@ -75,7 +79,73 @@ class clip:
 		# end_time = 25.0
 		# position_on_track = 3.0
 		
-
+	def update_thumbnail(self):
+		"""Updates the thumbnail of the clip to make it reflect the first frame.
+		   Creates a new thumbnail if there is none, gives it a new thumbnail path
+		   if it is empty."""
+	
+		# Initialize variables
+		project = self.parent.parent.project
+		thumbnailer = project.thumbnailer
+		fps = self.file_object.fps
+		start_frame = int(float(fps) * self.start_time)
+		file_type = self.file_object.file_type
+		
+		# Remove the thumbnail, if it can be removed
+		self.remove_thumbnail()
+	
+		# If it cannot be exchanged for the file thumbnail
+		if start_frame and (file_type == "video" or file_type == "image sequence"):
+		
+			# If it already has a thumbnail location, just update the thumbnail
+			if self.thumb_location and not self.thumb_location == self.file_object.thumb_location:
+				(dir_name, file_name) = os.path.split(self.thumb_location)
+				
+				# The shortened path to the thumbnail. %d is escaped to provide image sequence support
+				new_name = "thumbnail/" + file_name.replace("%d","%%d")
+				
+				# The whole path. %d shouldn't be escaped here.
+				path = project.folder + "/thumbnail/" + file_name
+				
+			# If the clip needs a new thumbnail location
+			else:
+			
+				# Split the file name
+				(dir_name, file_name) = os.path.split(self.file_object.name)
+				(file_base_name, ext) = os.path.splitext(file_name)
+				
+				# Escape some characters
+				ext = ext.replace(".", "")
+				
+				# Loop to find an unoccupied name. Start at 2, since the file thumbnail starts at 1
+				i = 2
+				while(True):
+					path = project.folder + "/thumbnail/" + file_base_name + "_" + ext + "_" + str(i) + ".png"
+					if not os.path.exists(path):
+						break
+					i += 1
+					
+				# The shortened path to the thumbnail. %d is escaped to provide image sequence support
+				new_name = "thumbnail/" + file_base_name.replace("%d","%%d") + "_" + ext + "_" + str(i) + ".png"
+	
+			# Create the new thumbnail
+			thumbnailer.get_thumb_at_frame(self.file_object.name, start_frame, new_name)
+			
+			# Update the path to the thumbnail
+			self.thumb_location = path
+			print "thumb " + self.thumb_location
+			
+		elif not file_type == "audio":
+			# Use the file thumbnail instead, to avoid creating a new
+			self.thumb_location = self.file_object.thumb_location
+			
+			
+	def remove_thumbnail(self):
+		"""Removes the thumbnail from the hard drive, if it isn't shared with a file"""
+		# Removes the thumbnail used by this clip if it is valid and isn't used by a file
+		if self.thumb_location and os.path.exists(self.thumb_location) and not self.thumb_location == self.file_object.thumb_location:
+			os.remove(self.thumb_location)
+		
 	def length(self):
 		# calculate the length of this clip (in decimal seconds)
 		length = self.end_time - self.start_time
@@ -114,6 +184,50 @@ class clip:
 				self.effects.append(new_effect)
 				self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Added effect") + " " + service)
 
+
+	def get_thumbnail(self, width, height):
+		"""Get and resize the pixbuf thumbnail for a clip"""	
+		
+		# get the thumbnail (or load default)
+		try:
+			if self.thumb_location:
+				pbThumb = gtk.gdk.pixbuf_new_from_file(self.thumb_location)
+				pbThumb = pbThumb.add_alpha(False, 255, 255, 255)
+				
+				# Mask the corner of the thumbnail image (for a nice rounding effect)
+				corner_mask = gtk.gdk.pixbuf_new_from_file(os.path.join(self.file_object.project.IMAGE_DIR, 'thumbnail_mask.png'))
+				corner_mask.composite(pbThumb, 
+								0, 
+								0, 
+								320, 
+								240, 
+								0, 
+								0, 
+								1.0, 
+								1.0, 
+								gtk.gdk.INTERP_NEAREST, 
+								255)
+
+				# replace corner with transparency
+				pbThumb = pbThumb.add_alpha(True, 255, 0, 202)
+
+
+			else:
+				# Load the No Thumbnail Picture
+				if self.file_object.file_type == "audio":
+					pbThumb = gtk.gdk.pixbuf_new_from_file(os.path.join(self.file_object.project.IMAGE_DIR, "AudioThumbnail.png"))
+				else:
+					pbThumb = gtk.gdk.pixbuf_new_from_file(os.path.join(self.file_object.project.IMAGE_DIR, "NoThumbnail.png"))
+		except:
+
+				# Load the No Thumbnail Picture
+				if self.file_object.file_type == "audio":
+					pbThumb = gtk.gdk.pixbuf_new_from_file(os.path.join(self.file_object.project.IMAGE_DIR, "AudioThumbnail.png"))
+				else:
+					pbThumb = gtk.gdk.pixbuf_new_from_file(os.path.join(self.file_object.project.IMAGE_DIR, "NoThumbnail.png"))
+
+		# resize thumbnail
+		return pbThumb.scale_simple(width, height, gtk.gdk.INTERP_BILINEAR)	
 	
 	def Remove_Effect(self, unique_id):
 		# Remove an effect from the list
@@ -274,13 +388,13 @@ class clip:
 			#blank = round(self.get_blank_space() * fps)
 			blank = frame_gap
 
-			if blank > 1:
+			if blank > 0:
 				# add blank xml node
 				blank_node = dom.createElement("blank")
 				blank_node.setAttribute("length", str(blank))
 				xmlParentNode.appendChild(blank_node)
 				
-		elif preview_mode == "trimming":
+		elif preview_mode in ["trimming", "clip-properties-preview"]:
 			# preview mode is True, always start at frame zero, and include the 
 			# entire clip in the preview XML (ignore the IN and OUT)
 			current_frame = 0
@@ -1230,7 +1344,7 @@ class clip:
 			# ///////////////////////////////////////////////////////	 
 			if has_regular_images == False:
 				# get the thumbnail image
-				pbThumb = self.file_object.get_thumbnail(theme_settings["clip"]["thumbnail"]["w"], theme_settings["clip"]["thumbnail"]["h"])
+				pbThumb = self.get_thumbnail(theme_settings["clip"]["thumbnail"]["w"], theme_settings["clip"]["thumbnail"]["h"])
 				
 				# create canvas image object
 				imgThumb = goocanvas.Image (parent = GroupClip,
@@ -1599,7 +1713,7 @@ class clip:
 		""" This method initializes some variables needed for dragging and dropping a clip """
 		# raise the group up to the top level
 		item.raise_(None)
-		
+
 		# set the x and y where the cursor started dragging from
 		self.drag_x = float(event.x)
 		self.drag_y = float(event.y)
@@ -1805,7 +1919,10 @@ class clip:
 		SecondClip.video_fade_amount = self.video_fade_amount
 
 		# copy original properties
-		SecondClip.keyframes = self.keyframes
+		SecondClip.keyframes = copy.deepcopy(self.keyframes)
+		
+		#copy original effects
+		SecondClip.effects = self.effects
 
 		# render new clip
 		SecondClip.RenderClip()
@@ -1928,57 +2045,71 @@ class clip:
 		(isArrow, isRazor, isSnap, isResize) = self.parent.parent.project.form.get_toolbar_options()
 		
 		if isArrow:
-
-			# get new parent track
-			drop_track = self.get_valid_drop(item.get_bounds().x1, item.get_bounds().y1)
 			
-			# update clip's settings to reflect the new x, y position (and update the parent track)
-			self.update(item.get_bounds().x1, item.get_bounds().y1, drop_track)
-			drop_track.reorder_clips()  
-	
-			# determine the direction of the drag
-			if isSnap:
-				distance_from_clip = self.get_snap_difference(self, item)
-			else:
-				distance_from_clip = 0.0
+			# only respond to the first mouse button
+			if event.button == 1:
 
-			# check if clip has been really moved or not
-			if ((self.stored_x == item.get_bounds().x1) and (self.stored_y == item.get_bounds().y1)):
-				# The clip was not moved
-				type_of_event = None
-			else:
-				# The clip has moved
-				type_of_event = _("Moved clip")
+				# get new parent track
+				drop_track = self.get_valid_drop(item.get_bounds().x1, item.get_bounds().y1)
 				
-				# Animate the clip to it's new position
-				item.animate(distance_from_clip, drop_track.y_top - item.get_bounds().y1 + 2, 1.0, 0.0, False, 200, 4, goocanvas.ANIMATE_FREEZE)
-					
-				# move the clip object on the timeline to correct position (snapping to the y and x of the track)		
-				item.translate (distance_from_clip, drop_track.y_top - item.get_bounds().y1 + 2)
-				
-				# update clip's settings again (since the snapping could have moved them a bit)
+				# update clip's settings to reflect the new x, y position (and update the parent track)
 				self.update(item.get_bounds().x1, item.get_bounds().y1, drop_track)
-				
-				# Mark clip as modified
-				self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = type_of_event)
-
-
-			if self.request_show_properties:
-				self.show_properties(item, 0)
+				drop_track.reorder_clips()  
+		
+				# determine the direction of the drag
+				if isSnap:
+					distance_from_clip = self.get_snap_difference(self, item)
+				else:
+					distance_from_clip = 0.0
+	
+				# check if clip has been really moved or not
+				if ((self.stored_x == item.get_bounds().x1) and (self.stored_y == item.get_bounds().y1)):
+					# The clip was not moved
+					type_of_event = None
+				else:
+					# The clip has moved
+					type_of_event = _("Moved clip")
+					
+					# Animate the clip to it's new position
+					item.animate(distance_from_clip, drop_track.y_top - item.get_bounds().y1 + 2, 1.0, 0.0, False, 200, 4, goocanvas.ANIMATE_FREEZE)
+						
+					# move the clip object on the timeline to correct position (snapping to the y and x of the track)		
+					item.translate (distance_from_clip, drop_track.y_top - item.get_bounds().y1 + 2)
+					
+					# update clip's settings again (since the snapping could have moved them a bit)
+					self.update(item.get_bounds().x1, item.get_bounds().y1, drop_track)
+					
+					# Mark clip as modified
+					self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = type_of_event)
+	
+	
+				if self.request_show_properties:
+					self.show_properties(item, 0)
 			
 		elif isResize:
 			
-			# remove clip from goocanvas
-			parent = item.get_parent()
-			child_num = parent.find_child (item)
-			parent.remove_child (child_num)			
+			# only respond to the first mouse button
+			if event.button == 1:
 			
-			# re-render the clip at it's new size
-			self.RenderClip()
-			
-			# switch video window back to 'view' mode (i.e. remove preview clip mode)
-			self.set_view_mode()
-			self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Resized clip"))
+				# remove clip from goocanvas
+				parent = item.get_parent()
+				child_num = parent.find_child (item)
+				parent.remove_child (child_num)			
+				
+				# Initialize variables
+				pixels_per_second = self.parent.parent.get_pixels_per_second()
+				center_of_clip = (self.position_on_track * pixels_per_second) + ((self.length() * pixels_per_second) / 2)
+				
+				# If the clip was dragged on the left side, update the thumbnail to reflect the changes
+				if event.x_root < center_of_clip:
+					self.update_thumbnail()
+				
+				# re-render the clip at it's new size
+				self.RenderClip()
+				
+				# switch video window back to 'view' mode (i.e. remove preview clip mode)
+				self.set_view_mode()
+				self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Resized clip"))
 				
  		# raise the play-head line, so it's not covered up
  		self.parent.parent.raise_transitions()
@@ -2038,76 +2169,80 @@ class clip:
 		
 		
 	def on_visible_click (self, item, target, event):
-		# get a reference to the language translate method
-		_ = self.parent.parent.project.translate		
+		# Left button
+		if event.button == 1:
+			# get a reference to the language translate method
+			_ = self.parent.parent.project.translate		
 
-		#don't do this if in razor mode
-		(isArrow, isRazor, isSnap, isResize) = self.parent.parent.project.form.get_toolbar_options()
-		if isArrow:
-			# get a reference to the 2 main canvas objects & theme
-			theme = self.parent.parent.project.theme
+			# don't do this if in razor mode
+			(isArrow, isRazor, isSnap, isResize) = self.parent.parent.project.form.get_toolbar_options()
+			if isArrow:
+				# get a reference to the 2 main canvas objects & theme
+				theme = self.parent.parent.project.theme
 			
-			# get the parent left group
-			parent_group = item.get_parent()
-			canvas = parent_group.get_canvas()
-			canvas.pointer_ungrab (item, event.time)
+				# get the parent left group
+				parent_group = item.get_parent()
+				canvas = parent_group.get_canvas()
+				canvas.pointer_ungrab (item, event.time)
 			
-			if self.play_video == True:
-				# Load Hover Over
-				imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/not_visible_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
-				item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
+				if self.play_video == True:
+					# Load Hover Over
+					imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/not_visible_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
+					item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
 	
-				# update play video variable
-				self.play_video = False
+					# update play video variable
+					self.play_video = False
 				
-			else: 
-				# Load normal image
-				imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/visible_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
-				item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
+				else: 
+					# Load normal image
+					imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/visible_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
+					item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
 	
-				# update play video variable
-				self.play_video = True
+					# update play video variable
+					self.play_video = True
 	
-			# mark project as modified
-			self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Changed visibility of clip"))
+				# mark project as modified
+				self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Changed visibility of clip"))
 	
 		# allow clip to receive click
 		return False
 	
 	
 	def on_audio_click (self, item, target, event):
-		# get a reference to the language translate method
-		_ = self.parent.parent.project.translate
+		# Left button
+		if event.button == 1:
+			# get a reference to the language translate method
+			_ = self.parent.parent.project.translate
 
-		#don't do this if in razor mode.
-		(isArrow, isRazor, isSnap, isResize) = self.parent.parent.project.form.get_toolbar_options()
-		if isArrow:
-			# get a reference to the 2 main canvas objects & theme
-			theme = self.parent.parent.project.theme
+			# don't do this if in razor mode.
+			(isArrow, isRazor, isSnap, isResize) = self.parent.parent.project.form.get_toolbar_options()
+			if isArrow:
+				# get a reference to the 2 main canvas objects & theme
+				theme = self.parent.parent.project.theme
 		
-			# get the parent left group
-			parent_group = item.get_parent()
-			canvas = parent_group.get_canvas()
-			canvas.pointer_ungrab (item, event.time)
+				# get the parent left group
+				parent_group = item.get_parent()
+				canvas = parent_group.get_canvas()
+				canvas.pointer_ungrab (item, event.time)
 		
-			if self.play_audio == True:
-				# Load Hover Over
-				imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/speaker_mute_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
-				item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
+				if self.play_audio == True:
+					# Load Hover Over
+					imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/speaker_mute_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
+					item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
 			
-				# update play video variable
-				self.play_audio = False
+					# update play video variable
+					self.play_audio = False
 				
-			else: 
-				# Load normal image
-				imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/speaker_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
-				item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
+				else: 
+					# Load normal image
+					imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/speaker_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
+					item.set_properties(pixbuf = imgTrack_Visible.get_pixbuf())
 				
-				# update play video variable
-				self.play_audio = True
+					# update play video variable
+					self.play_audio = True
 
-			# mark project as modified
-			self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Changed audio of clip"))
+				# mark project as modified
+				self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Changed audio of clip"))
 
 		# allow clip to receive click
 		return False
