@@ -121,7 +121,7 @@ class effect:
 					sox_value = sox_value + " " + v
 					
 				# add value
-				text = dom.createTextNode("%s %s%s" % (audio_effect, audio_effect, sox_value))
+				text = dom.createTextNode("%s %s" % (audio_effect, sox_value))
 				property_node.appendChild(text)
 				# append to the filter node
 				filter_root.appendChild(property_node)
@@ -183,6 +183,8 @@ class effect_param_metadata:
 		self.type = ""
 		self.min = 0.0
 		self.max = 0.0
+		self.step = 0.10
+		self.digits = 2
 		self.default = 0.0
 		self.values = {}
 
@@ -253,6 +255,12 @@ def get_effects(project=None, directory=None):
 				if param.getElementsByTagName("max"):
 					param1.max = param.getElementsByTagName("max")[0].childNodes[0].data
 					
+				if param.getElementsByTagName("step"):
+					param1.step = param.getElementsByTagName("step")[0].childNodes[0].data
+					
+				if param.getElementsByTagName("digits"):
+					param1.digits = param.getElementsByTagName("digits")[0].childNodes[0].data
+					
 				if param.getElementsByTagName("default"):
 					if param.getElementsByTagName("default")[0].childNodes:
 						param1.default = param.getElementsByTagName("default")[0].childNodes[0].data
