@@ -54,6 +54,11 @@ class OpenShotFile:
 		self.parent = None
 		self.project = project	  # reference to project
 		
+		self.video_codec = ""
+		self.audio_codec = ""
+		self.audio_frequency = ""
+		self.audio_channels = ""
+		
 		
 	def get_thumbnail(self, width, height):
 		"""Get and resize the pixbuf thumbnail for a file"""	
@@ -99,6 +104,26 @@ class OpenShotFile:
 		# resize thumbnail
 		return pbThumb.scale_simple(width, height, gtk.gdk.INTERP_BILINEAR)	
 		
+	def update_thumbnail(self):
+	
+		# Initialize variables
+		project = self.project
+		thumbnailer = project.thumbnailer
+		file_type = self.file_type
+		
+		# Audio files have a common thumbnail
+		if not file_type == "audio":	
+		
+			# Split the file name
+			(dir_name, file_name) = os.path.split(self.name)
+			(file_base_name, ext) = os.path.splitext(file_name)
+			ext = ext.replace(".", "")
+			
+			# The shortened path to the thumbnail
+			new_name = "thumbnail/" + file_base_name + "_" + ext + "_1.png"
+			
+			# Create the new thumbnail
+			thumbnailer.get_thumb_at_frame(self.name, new_name=new_name)
 
 ########################################################################
 class OpenShotFolder:
@@ -113,6 +138,9 @@ class OpenShotFolder:
 		self.location = ""	  # file system location
 		self.parent = None
 		self.project = project
+		
+		self.label = ""		  # user description of the folder
+		self.unique_id = str(uuid.uuid1())
 
 		# init the list of files & folders
 		# this list can contain OpenShotFolder or OpenShotFile objects
@@ -149,23 +177,37 @@ class OpenShotFolder:
 	#----------------------------------------------------------------------
 	def AddFile(self, file_name, session=None, ignore_image_sequences=False):
 		"""Add a new file to the current folder"""
+		"""
+		Returns a tuple: 
+		(The number of files that could be successfully imported (not including folders),
+		The number of files that could not be imported (wrong format),
+		The number of files already imported to the project,
+		The number of folders selected (0 or 1))
+		"""
 		
 		import urllib
 		
 		# get a reference to the language translate method
 		_ = self.project.translate
 		
-		# clean path to video
+		# clean path to file
 		file_name = urllib.unquote(file_name)
 		newFile = None
 		
-		# don't add a file that is already in this folder (i.e. dupe check)
-		if self.file_exists_in_project(file_name):
-			return
+		# The number of ok files (not counting folders)
+		ok_files = 0
+		# The number of files that couldn't be read (wrong format)
+		broken_files = 0
+		# The number of duplicates in the project
+		duplicate_files = 0
+		# The number of folders submitted (0 or 1)
+		folders = 0
 			
 		# check if the path is a 'folder' and not a file
 		if os.path.isdir(file_name):
 			
+			folders += 1
+			
 			# loop through each sub-file (if any)
 			for sub_file in os.listdir(file_name):
 				sub_file_path = os.path.join(file_name, sub_file)
@@ -173,42 +215,61 @@ class OpenShotFolder:
 				# only add files
 				if os.path.isfile(sub_file_path):
 					
-					# don't add a file that is alrady in this folder (i.e. dupe check)
+					# don't add a file that is already in the project (i.e. dupe check)
 					if self.file_exists_in_project(sub_file_path) == False:
 
 						# inspect the media file and generate it's thumbnail image (if any)
 						newFile = self.project.thumbnailer.GetFile(sub_file_path)
-						
+					
 						# add to internal item collection
 						if newFile:
+							ok_files += 1
 							self.items.append(newFile)
+						else:
+							broken_files += 1
+					else:
+						duplicate_files += 1
 
 		else:
+		
+			# don't add a file that is already in this folder (i.e. dupe check)
+			if self.file_exists_in_project(file_name):
+				duplicate_files += 1
+				return (ok_files, broken_files, duplicate_files, folders)
+			
 			# should we ignore image sequence check?
 			if ignore_image_sequences:
 				
 				# inspect the media file and generate it's thumbnail image (if any)
 				newFile = self.project.thumbnailer.GetFile(file_name)
-			
+				
 				# add to internal item collection
 				if newFile:
+					ok_files += 1
 					self.items.append(newFile)
+				else:
+					broken_files += 1
 
 			# determine if this is an image sequence
 			elif not self.GetImageSequenceDetails(file_name, session):
-
+			
 				# inspect the media file and generate it's thumbnail image (if any)
 				newFile = self.project.thumbnailer.GetFile(file_name)
 			
 				# add to internal item collection
 				if newFile:
+					ok_files += 1
 					self.items.append(newFile)
+				else:
+					broken_files += 1
+			else:
+				ok_files += 1
 
 		# mark project as modified
 		if newFile:
 			self.project.set_project_modified(is_modified=True, refresh_xml=False, type=_("Added file"))
 		
-		return newFile
+		return (ok_files, broken_files, duplicate_files, folders)
 	
 	
 	def GetImageSequenceDetails(self, file_path, session=None):
@@ -314,31 +375,89 @@ class OpenShotFolder:
 		self.project.form.refresh_files()
 	
 	#----------------------------------------------------------------------
-	def ConvertFileToImages(self, file_name):
+	def ConvertFileToImages(self, file_location, start_time=0.00, end_time=None):
 		"""Add a new file to the current folder"""
+		"""
+		file_location: The location of the file to convert.
+		start_time: The time to grab the first image.
+		end_time: The time to grab the last image. None=last frame
+		"""
 		
 		import urllib
 		
 		# get a reference to the language translate method
 		_ = self.project.translate
+		
+		# get a reference to the file
+		f = self.project.project_folder.FindFile(file_location)
 
 		# clean path to video
-		file_name = urllib.unquote(file_name)
+		file_location = urllib.unquote(file_location)
+		
+		# True if only a part of the file should be converted.
+		is_part = True
+		if start_time == 0.00 and (end_time == None or end_time == f.length):
+			is_part = False
+		
+		# get file name, path, and extension
+		(dirName, filename) = os.path.split(file_location)
+		(fileBaseName, fileExtension)=os.path.splitext(filename)
+		# the folder path if the image sequence is not a part (inside the same folder as the movie file)
+		new_folder_path = os.path.join(dirName, fileBaseName)
+	
 
 		# check if this file is already in the project
 		for item in self.items:
-			if file_name in item.name and item.file_type == _("Image Sequence").lower():
-				return True
-			
-		# inspect the media file and generate it's thumbnail image (if any)
-		newFile = self.project.thumbnailer.GetFile(file_name, all_frames=True)
+			if not is_part and item.file_type == _("Image Sequence").lower():
+				(itemBase, itemExt) = os.path.split(item.name)
+				if new_folder_path == itemBase:
+					return True
 		
+		# Create folder(s)
+		
+		# if file is a video
+		if f.file_type == "video":
+			
+			# create thumbnail folder (if it doesn't exist)
+			if os.path.exists(new_folder_path) == False:
+				os.mkdir(new_folder_path)
+			
+			# part of the clip will be converted
+			if is_part:
+				
+				# counter
+				x = 1
+				
+				while(True):
+					
+					# add "_x" to the name, so the folder has the name "base_x", and the first image will
+					# have the name "base_x_1"
+					new_file_base_name = fileBaseName + "_" + str(x)
+					# create a new folder for this file (inside the previously created folder)
+					new_folder_path = os.path.join(dirName, fileBaseName, new_file_base_name)
+			
+					# create thumbnail folder (if it doesn't exist)
+					# FIXME: (TJ) This doesn't use thumbnail_path - should it?
+					if os.path.exists(new_folder_path) == False:
+						os.mkdir(new_folder_path)
+					
+					# if the directory is empty
+					if not os.listdir(new_folder_path):
+						
+						# inspect the media file and generate it's thumbnail image (if any)
+						newFile = self.project.thumbnailer.GetFile(file_location, False, new_file_base_name, start_time, end_time)
+					
+						break
+					
+					x += 1
+			# whole clip
+			else:
+				# get the image sequence
+				newFile = self.project.thumbnailer.GetFile(file_location, False)
+				
 		# update the location
 		if newFile:
-			(dirName, fname) = os.path.split(file_name)
-			(fileBaseName, fileExtension)=os.path.splitext(fname)
-			newFile.name = os.path.join(dirName, fileBaseName, fileBaseName + "_%d.png")
-	
+			
 			# add to internal item collection
 			self.items.append(newFile)
 
@@ -348,10 +467,18 @@ class OpenShotFolder:
 	def file_exists_in_project(self, file_name):
 		""" Check if this file exists in this project """
 		
-		# don't add a file that is alrady in this folder (i.e. dupe check)
+		# check if file exists
+		if not os.path.exists(file_name):
+			# File does not exist!
+			return False
+		
+		# don't add a file that is already in this folder (i.e. dupe check)
 		for item in self.items:
-			if file_name in item.name:
-				return True
+			
+			if isinstance(item, OpenShotFile):
+				if item.file_type != "image sequence":
+					if os.path.samefile(file_name, item.name):
+						return True
 		
 		# didn't find a match
 		return False
@@ -378,12 +505,15 @@ class OpenShotFolder:
 		return path
 
 
-	def UpdateFileLabel(self, filename, value, refresh_tree=0):
+	def UpdateFileLabel(self, unique_id, value, refresh_tree=0):
 		#this will only be called when the treeview mode is selected, not the thumbview 
 		for item in self.items:
-			if item.name.endswith(filename):
+			if item.unique_id == unique_id:
 				item.label = value
 				
+				# mark project as modified
+				self.project.set_project_modified(is_modified=True, refresh_xml=True, type=_("Updated Label"))
+				
 		if refresh_tree == 1:
 			# Update the main form
 			self.project.form.refresh_files()
@@ -396,24 +526,29 @@ class OpenShotFolder:
 		
 		item = self.FindFile(filename)
 		if item:
-			# mark project as modified
-			self.project.set_project_modified(is_modified=True, refresh_xml=True, type=_("Removed file"))
 			
 			# find clips that have this file object
 			for track in self.project.sequences[0].tracks:
 				for clip in reversed(track.clips):
 					# does clip match file
 					if clip.file_object == item:
-						# delete clip
+						# delete clip and remove thumbnail
 						track.clips.remove(clip)
+						clip.remove_thumbnail()
+			
 			# remove from file collection
 			self.items.remove(item)
+			# mark project as modified
+			self.project.set_project_modified(is_modified=True, refresh_xml=True, type=_("Removed file"))
+			
 		else:
 			#is this a folder?
 			item = self.FindFolder(filename)
 			if item:
 				# remove from file collection
 				self.items.remove(item)
+				# mark project as modified
+			self.project.set_project_modified(is_modified=True, refresh_xml=True, type=_("Removed folder"))
 
   
 	#----------------------------------------------------------------------
@@ -504,3 +639,19 @@ class OpenShotFolder:
 			
 			# mark project as modified
 			self.project.set_project_modified(is_modified=True, refresh_xml=False, type=_("Removed from folder"))
+			
+	#----------------------------------------------------------------------
+	def __setstate__(self, state):
+		""" This method is called when an OpenShot project file is un-pickled (i.e. opened).  It can
+		    be used to update the structure of old clip classes, to make old project files compatable with
+		    newer versions of OpenShot. """
+	
+		# Check for missing DEBUG attribute (which means it's an old project format)
+		if 'label' not in state:
+			state['label'] = ""
+		if 'unique_id' not in state:
+			state['unique_id'] = str(uuid.uuid1())
+
+		# update the state object with new schema changes
+		self.__dict__.update(state)
+		
