@@ -16,8 +16,8 @@
 #	You should have received a copy of the GNU General Public License
 #	along with OpenShot Video Editor.  If not, see <http://www.gnu.org/licenses/>.
 
-VERSION             = "1.3.1"
-DATE                = "20110503000000"
+VERSION             = "1.4.0"
+DATE                = "20110921000000"
 NAME                = 'openshot'
 GPL_VERSION         = '3'
 SUPPORTED_LANGUAGES = ['English', 'Dutch', 'French', 'German', 'Italian', 'Portuguese', 'Spanish', 'Swedish']
@@ -31,10 +31,12 @@ TJ   = {'name': u'TJ', 'email': 'ubuntu@tjworld.net'}
 MA   = {'name': u'Mael Lavault', 'email': 'moimael@neuf.fr'}
 IM   = {'name': u'itomailg', 'email': 'itomailg@gmail.com'}
 JS   = {'name': u'jEsuSdA', 'email': 'info@jesusda.com'}
+FF   = {'name': u'Francesco Fantoni', 'email': 'francesco@hv-a.com'}
+EB   = {'name': u'Emil Berg', 'email': 'emil_berg91@hotmail.com'}
 
 #credits
 CREDITS = {
-    'code'          : [JT, AF, TJ, OG, MA, IM],
+    'code'          : [JT, AF, TJ, OG, MA, IM, FF, EB],
     'artwork'       : [JT, JS],
     'documentation' : [OG, JT, HMC],
     'translation'   : [HMC, OG],
