@@ -34,26 +34,32 @@ class thumbnailer ( threading.Thread ):
 		""" Associate the OpenShot project file with this threaded class. """
 		self.project = project
 		
-	def GetFile(self, file_name, all_frames=False):
+	def GetFile(self, file_location, only_thumbnail=True, new_file_base_name=None, start_time=0.00, end_time=None):
 		""" Use this method to generate an OpenShotFile object based on the URL (or file location)
 		of a video or audio file. Each time you call this method, it will lock this thread (and OpenShot's
 		main thread) until it has finished. """
+		""" 
+		file_location: The location of the file on the hard drive, including the name and extension.
+		only_thumbnail: True if only a thumbnail should be grabbed from the file, False if image sequence.
+		new_file_base_name: The name of the folder and the base for the image sequence name, not including the path.
+		start_time: The time to start grabbing frames from the file, in seconds.
+		end_time: The time to end grabbing frames from the file, in seconds. None = To the last frame.
+		"""
 
 		try:
 			
 			# determine name and location of thumbnail image
-			self.file_name = file_name
+			self.file_name = file_location
 			self.thumbnail_path = ""
 			self.file_type = "video"
 			self.label = ""
 			project_path = self.project.folder
-			myPath = self.file_name
-			(dirName, fileName) = os.path.split(myPath)
-			(fileBaseName, fileExtension)=os.path.splitext(fileName)
+			(dirName, fileName) = os.path.split(file_location)
+			(fileBaseName, fileExtension) = os.path.splitext(fileName)
 			fileExtension = fileExtension.replace(".", "")
 			actual_thumbnail_path = project_path + "/thumbnail/" + fileBaseName + "_" + fileExtension + "_1.png"
 
-			if all_frames == False:
+			if only_thumbnail:
 				# just get 1 thumbnail frame
 				self.thumbnail_path = project_path + "/thumbnail/" + fileBaseName + "_" + fileExtension + "_%d.png"
 				
@@ -61,17 +67,18 @@ class thumbnailer ( threading.Thread ):
 				self.profile = mlt.Profile("quarter_ntsc")
 
 			else:
-				# export all frames of the video
-				self.thumbnail_path = dirName + "/" + fileBaseName + "/" + fileBaseName + "_%d.png"
-				
-				# set the profile
-				self.profile = profiles.mlt_profiles(self.project).get_profile(self.project.project_type)
-
+				if new_file_base_name == None or new_file_base_name == fileBaseName:
+					# choose the same folder as the name (without extension) as default
+					self.thumbnail_path = os.path.join(dirName, fileBaseName, fileBaseName + "_%d.png")
+				else:
+					# export a part of the video to a folder under the folder with the same name as the file.
+					self.thumbnail_path = os.path.join(dirName, fileBaseName, new_file_base_name, new_file_base_name + "_%d.png")
+			
 			# re-init the mlt factory
 			mlt.Factory.init()
 				
 			# Create the producer
-			self.p = mlt.Producer( self.profile, '%s' % self.file_name )
+			self.p = mlt.Producer( self.profile, '%s' % file_location )
 			
 			# Check if clip is valid (otherwise a seg fault)
 			if self.p.is_valid() == False:
@@ -85,34 +92,74 @@ class thumbnailer ( threading.Thread ):
 			self.c.set("vcodec", "png")
 
 			# determine length of clip in seconds
-			max_frames = float(self.p.get_length()) - 1.0
 			producer_fps = float(self.p.get_fps())
-			calculate_length = max_frames / producer_fps
-
+			first_frame = int(round(producer_fps * start_time))
+			# Whole clip if end_time = None 
+			if end_time == None:
+				last_frame = self.p.get_length()
+			else:
+				last_frame = int(round(producer_fps * end_time))
+			max_frames = last_frame - first_frame
+		
+			# determine dimensions			
+			
 			height = 0
 			width = 0
 			if self.p.get("height"):
 				height = int(self.p.get("height"))
 			if self.p.get("width"):
 				width = int(self.p.get("width"))
-
+				
+			audio_index = self.p.get_int("audio_index")
+			video_index = self.p.get_int("video_index")
+			audio_property = "meta.media.%s.codec.long_name" % audio_index
+			if self.p.get(audio_property):
+				self.audio_codec = self.p.get(audio_property)
+			else:
+				self.audio_codec = ""
+					
+			video_property = "meta.media.%s.codec.long_name" % video_index
+			if self.p.get(video_property):
+				self.video_codec = self.p.get(video_property)
+			else:
+				self.video_codec = ""
+			
+			if self.p.get_frame():
+				frame = self.p.get_frame()
+				self.audio_frequency = frame.get_int("frequency")
+				self.audio_channels = frame.get_int("channels")
+			
 			# determine if this is an image
 			is_image = False
-			if self.p.get_length() == 15000:
+			if self.p.get_length() == 15000 and video_index == 0 and audio_index == 0:
 				# images always have exactly 15000 frames
 				is_image = True
-				self.file_type = "image"
+				self.file_type = "image"	
+
+			# determine if this is an image
+			#is_image = False
+			#if self.p.get_length() == 15000:
+				# images always have exactly 15000 frames
+				#is_image = True
+				#self.file_type = "image"
 				
 				# set the max length of the image to 300 seconds (i.e. 5 minutes)
 				max_frames = producer_fps * 300
 				
+				# get actual height & width of image (since MLT defaults to 1 x 1)
+				width, height = self.get_image_size(file_location)
+		
+			# determine length
+			if only_thumbnail:
+				calculate_length = self.p.get_length() / producer_fps
+			else:
+				calculate_length = max_frames / producer_fps
+			if is_image:
+				
 				# set the length to 300 seconds (i.e. 5 minutes)
 				calculate_length = float(300)
 
-				# get actual height & width of image (since MLT defaults to 1 x 1)
-				width, height = self.get_image_size(self.file_name)
-
-
+				
 			# set thumbnail image (if no height & width are detected)
 			if (height == False or width == False) and (is_image == False):
 				self.thumbnail_path = ""
@@ -120,9 +167,12 @@ class thumbnailer ( threading.Thread ):
 
 
 			# get the 1st frame (if not exporting all frames)
-			if all_frames == False:
+			if only_thumbnail:
+				max_frames = float(self.p.get_length()) - 1.0
 				self.p = self.p.cut(1, 1)
+				# get the frames in an interval
 			else:
+				self.p = self.p.cut(first_frame, last_frame)
 				# mark as image seq
 				self.label = "Image Sequence"
 				self.file_type = "image sequence"
@@ -138,7 +188,11 @@ class thumbnailer ( threading.Thread ):
 	
 			# create an openshot file object
 			newFile = files.OpenShotFile(self.project)
-			newFile.name = self.file_name
+			# thumbnails and image sequences are stored at different locations
+			if only_thumbnail:
+				newFile.name = file_location
+			else:
+				newFile.name = self.thumbnail_path
 			newFile.length = calculate_length
 			newFile.thumb_location = actual_thumbnail_path
 			newFile.videorate = (self.p.get_fps(), 0)
@@ -148,12 +202,16 @@ class thumbnailer ( threading.Thread ):
 			newFile.fps = producer_fps
 			newFile.file_type = self.file_type
 			newFile.label = self.label
+			newFile.audio_channels = self.audio_channels
+			newFile.audio_codec = self.audio_codec
+			newFile.audio_frequency = self.audio_frequency
+			newFile.video_codec = self.video_codec
 
 			# return the OpenShotFile object
 			return newFile
 		
 		except Exception:
-			print "Failed to import file: %s" % file_name
+			print "Failed to import file: %s" % file_location
 
 
 
