@@ -167,6 +167,27 @@ class transition:
 		return GroupTransition
 	
 	
+	def change_direction_image(self, GroupTransition):
+		
+		# don't change direction of a mask
+		if self.type != "transition":
+			return
+		
+		# get a reference to the 2 main canvas objects & theme
+		theme = self.parent.parent.project.theme
+		
+		# get the direction image
+		canvasImageTrans = self.get_canvas_child(GroupTransition, "trans_direction")
+	
+		if self.reverse:
+			# DOWN
+			imgTrans = gtk.image_new_from_file("%s/openshot/themes/%s/transition_down.png" % (self.parent.parent.project.form.openshot_path, theme))
+			canvasImageTrans.set_properties(pixbuf = imgTrans.get_pixbuf())
+		else:
+			# UP
+			imgTrans = gtk.image_new_from_file("%s/openshot/themes/%s/transition_up.png" % (self.parent.parent.project.form.openshot_path, theme))
+			canvasImageTrans.set_properties(pixbuf = imgTrans.get_pixbuf())
+	
 	
 	def get_canvas_child(self, group, requested_child_id):
 		"""this method loops though the children objects of this group looking 
@@ -424,6 +445,17 @@ class transition:
 			self.update_parent(drop_track)
 			drop_track.reorder_transitions()
 			
+			if isSnap:
+				# update direction of transition (only in snap mode)
+				direction = self.get_direction(self, item)
+				if direction == "down":
+					self.reverse = True
+				else:
+					self.reverse = False
+				
+				# refresh image
+				self.change_direction_image(item)
+			
 			# Animate the transition to it's new position
 			item.animate(distance_from_clip, bottom_y - item.get_bounds().y1, 1.0, 0.0, False, 200, 4, goocanvas.ANIMATE_FREEZE)
 				
@@ -496,6 +528,10 @@ class transition:
 		# get the index of this transition (from the parent collection)
 		clip_index = clip_object.parent.transitions.index(clip_object)
 		clip_length = clip_object.length * pixels_per_second
+		track_index = self.parent.parent.tracks.index(self.parent)
+		bottom_track = None
+		if (track_index + 1) <= (len(self.parent.parent.tracks) - 1):
+			bottom_track = self.parent.parent.tracks[track_index + 1]
 		closest_clip = None
 		distance_from_clip = 0.0
 		distance_from_left_clip = 0.0
@@ -508,51 +544,71 @@ class transition:
 			direction = "left"
 		else:
 			direction = "right"
-			
-		# get distance from nearby clips (if any)
+		
+		# Look on TOP TRACK
+		# get distance from nearby clips (to the LEFT)
 		nearby_clip_left = self.get_edge_of_clip(canvas_item.get_bounds().x1 / pixels_per_second, "left", self.parent) * pixels_per_second
 		distance_from_left_clip = nearby_clip_left - canvas_item.get_bounds().x1
 		
-		nearby_clip_right = distance_from_right_clip = self.get_edge_of_clip(canvas_item.get_bounds().x2 / pixels_per_second, "right", self.parent) * pixels_per_second
+		# get distance from nearby clips (to the RIGHT)
+		nearby_clip_right = self.get_edge_of_clip(canvas_item.get_bounds().x2 / pixels_per_second, "right", self.parent) * pixels_per_second
 		distance_from_right_clip = (nearby_clip_right + 1) - canvas_item.get_bounds().x2
 		
-#		# if there is a transition to the left of this one, find the distance to it's edge
-#		if (clip_index - 1) >= 0 and (clip_index - 1) < len(clip_object.parent.transitions):
-#			closest_clip = clip_object.parent.transitions[clip_index - 1]
-#			clip_x = closest_clip.position_on_track * pixels_per_second
-#			closest_clip_length = closest_clip.length * pixels_per_second
-#			closest_clip_position = clip_x + closest_clip_length
-#			distance_from_left_clip = closest_clip_position - canvas_item.get_bounds().x1
-#
-#		# if there is a transition to the right of this one, find the distance to it's edge
-#		if (clip_index + 1) >= 0 and (clip_index + 1) < len(clip_object.parent.transitions):
-#			closest_clip = clip_object.parent.transitions[clip_index + 1]
-#			closest_clip_position = closest_clip.position_on_track * pixels_per_second
-#			distance_from_right_clip = closest_clip_position - (canvas_item.get_bounds().x1 + clip_length)
+		# check bottom track (if any)
+		BOTTOM_distance_from_left_clip = 0.0
+		BOTTOM_distance_from_right_clip = 0.0
+		if bottom_track:
+			# BOTTOM TRACK
+			# get distance from nearby clips (to the LEFT)
+			BOTTOM_nearby_clip_left = self.get_edge_of_clip(canvas_item.get_bounds().x1 / pixels_per_second, "left", bottom_track) * pixels_per_second
+			BOTTOM_distance_from_left_clip = BOTTOM_nearby_clip_left - canvas_item.get_bounds().x1
 			
+			# get distance from nearby clips (to the RIGHT)
+			BOTTOM_nearby_clip_right = self.get_edge_of_clip(canvas_item.get_bounds().x2 / pixels_per_second, "right", bottom_track) * pixels_per_second
+			BOTTOM_distance_from_right_clip = (BOTTOM_nearby_clip_right + 1) - canvas_item.get_bounds().x2
+
+		
 		# distance from the play-head
 		playhead_time = clip_object.parent.parent.play_head_position
 		playhead_pixels = playhead_time * pixels_per_second
 		distance_from_playhead = playhead_pixels - canvas_item.get_bounds().x1
 		
+#		print "----------------"
+#		print "distance_from_left_clip: %s" % distance_from_left_clip
+#		print "distance_from_right_clip: %s" % distance_from_right_clip
+#		print "BOTTOM_distance_from_left_clip: %s" % BOTTOM_distance_from_left_clip
+#		print "BOTTOM_distance_from_right_clip: %s" % BOTTOM_distance_from_right_clip
+#		print "distance_from_playhead: %s" % distance_from_playhead
 
 		# limit the left /right snapping to 10 pixels
 		if distance_from_left_clip > 10 or distance_from_left_clip < -10:
 			distance_from_left_clip = 0.0
 		if distance_from_right_clip > 10 or distance_from_right_clip < -10:
 			distance_from_right_clip = 0.0
+		if BOTTOM_distance_from_left_clip > 10 or BOTTOM_distance_from_left_clip < -10:
+			BOTTOM_distance_from_left_clip = 0.0
+		if BOTTOM_distance_from_right_clip > 10 or BOTTOM_distance_from_right_clip < -10:
+			BOTTOM_distance_from_right_clip = 0.0
 		if distance_from_playhead > 10 or distance_from_playhead < -10:
 			distance_from_playhead = 0.0
 
 		# determine which direction and what clip to snap to (based on the direction the clip is moving)
 		if direction == "left" and distance_from_left_clip != 0:
 			distance_from_clip = distance_from_left_clip
+		if direction == "left" and BOTTOM_distance_from_left_clip != 0:
+			distance_from_clip = BOTTOM_distance_from_left_clip
 		elif direction == "right" and distance_from_right_clip != 0:
 			distance_from_clip = distance_from_right_clip
+		elif direction == "right" and BOTTOM_distance_from_right_clip != 0:
+			distance_from_clip = BOTTOM_distance_from_right_clip
 		elif distance_from_left_clip != 0:
 			distance_from_clip = distance_from_left_clip
 		elif distance_from_right_clip != 0:
 			distance_from_clip = distance_from_right_clip
+		elif BOTTOM_distance_from_left_clip != 0:
+			distance_from_clip = BOTTOM_distance_from_left_clip
+		elif distance_from_right_clip != 0:
+			distance_from_clip = distance_from_right_clip
 		elif distance_from_playhead != 0:
 			distance_from_clip = distance_from_playhead
 
@@ -597,5 +653,55 @@ class transition:
 		return 0.0
 		
 		
+	def get_direction(self, clip_object, canvas_item):
+		""" Guess the direction of the transition based on the position
+		of the surrounding clips. """
+
+		# get the pixels per second from the parent sequence
+		pixels_per_second = clip_object.parent.parent.get_pixels_per_second()
+
+		# get the index of this transition (from the parent collection)
+		track_index = self.parent.parent.tracks.index(self.parent)
+		bottom_track = None
+		if (track_index + 1) <= (len(self.parent.parent.tracks) - 1):
+			bottom_track = self.parent.parent.tracks[track_index + 1]
+			
+		transition_start = self.position_on_track
+		transition_end = self.position_on_track + self.length
 		
+		# loop through clips on the TOP track
+		TOP_left_position = 0.0
+		TOP_found = False
+		for clip in self.parent.clips:
+			# get right edge of clip
+			clip_start = float(clip.position_on_track)
+			clip_end = float(clip.position_on_track + clip.length())
+			
+			# does clip overlap transition
+			if (clip_end >= transition_start and clip_end <= transition_end) or (clip_start >= transition_start and clip_start <= transition_end) or (clip_start >= transition_start and clip_end <= transition_end) or (clip_start <= transition_start and clip_end >= transition_end):
+				TOP_found = True
+				TOP_left_position = clip_start
+				break
+			
+		# loop through clips on the BOTTOM track
+		BOTTOM_left_position = 0.0
+		BOTTOM_found = False
+		for clip in bottom_track.clips:
+			# get right edge of clip
+			clip_start = float(clip.position_on_track)
+			clip_end = float(clip.position_on_track + clip.length())
+			
+			# does clip overlap transition
+			if (clip_end >= transition_start and clip_end <= transition_end) or (clip_start >= transition_start and clip_start <= transition_end) or (clip_start >= transition_start and clip_end <= transition_end) or (clip_start <= transition_start and clip_end >= transition_end):
+				BOTTOM_found = True
+				BOTTOM_left_position = clip_start
+				break
+				
+		if TOP_found == True and BOTTOM_found == True:
+			if TOP_left_position <= BOTTOM_left_position:
+				return "down"
+			else:
+				return "up"
+		else:
+			return None
 		
