@@ -72,7 +72,8 @@ class Translator:
 		
 		# Setup foreign language support
 		langs = []
-		lc, encoding = locale.getdefaultlocale()
+		#lc, encoding = locale.getdefaultlocale()
+		lc, encoding = locale.getlocale(locale.LC_MESSAGES)
 
 		if (lc):
 			langs = [lc]			
