@@ -86,6 +86,7 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		
 		# init the default properties
 		self.txtFileName.set_text(fname)
+		self.spinbtnStart.set_value(self.current_clip.position_on_track)
 		self.txtLength.set_text(_("{0} seconds").format(str(self.current_clip.length())))
 		self.txtIn.set_value(round(self.current_clip.start_time, 2))
 		self.txtOut.set_value(round(self.current_clip.end_time, 2))
@@ -139,7 +140,7 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		# mark project as modified
 		# so that the real project is refreshed... even if these 
 		# preview changes are not accepted
-		self.project.set_project_modified(is_modified=False, refresh_xml=True)
+		self.project.set_project_modified(is_modified=True, refresh_xml=True)
 
 		
 	def restore_window_size(self):
@@ -189,6 +190,7 @@ class frmClipProperties(SimpleGtkBuilderApp):
 				# get hbox
 				hbox = self.vbox_effect_settings.get_children()[param_index]
 				label = hbox.get_children()[0]
+				self.sizegroup1.add_widget(label)
 				
 				# Get actual value for param
 				user_param_value = self.get_clip_parameter(clip_effect, param.name)
@@ -199,8 +201,8 @@ class frmClipProperties(SimpleGtkBuilderApp):
 
 				if param.type == "spinner":
 					# create spinner
-					adj = gtk.Adjustment(float(user_param_value), float(param.min), float(param.max), 0.01, 0.01, 0.0)
-					spinner = gtk.SpinButton(adj, 0.01, 2)
+					adj = gtk.Adjustment(float(user_param_value), float(param.min), float(param.max), float(param.step), float(param.step), 0.0)
+					spinner = gtk.SpinButton(adj, float(param.step), int(param.digits))
 					# connect signal 
 					spinner.connect("value-changed", self.effect_spinner_changed, real_effect, param, unique_id)
 					# add to hbox
@@ -208,8 +210,9 @@ class frmClipProperties(SimpleGtkBuilderApp):
 					
 				elif param.type == "hscale":
 					# create hscale
-					adj = gtk.Adjustment(float(user_param_value), float(param.min), float(param.max), 0.0, 0.0, 1.0)
+					adj = gtk.Adjustment(float(user_param_value), float(param.min), float(param.max), float(param.step), float(param.step), 0.0)
 					hscale = gtk.HScale(adj)
+					hscale.set_digits(int(param.digits))
 					# connect signal 
 					hscale.connect("value-changed", self.effect_hscale_changed, real_effect, param, unique_id)
 					# add to hbox
@@ -293,6 +296,7 @@ class frmClipProperties(SimpleGtkBuilderApp):
 					# find the matching param
 					if param.name in clip_param.keys():
 						# update the param
+						print widget.get_value()
 						clip_param[param.name] = str(widget.get_value())
 						return
 		
@@ -357,21 +361,29 @@ class frmClipProperties(SimpleGtkBuilderApp):
 			child_index = child_index + 1
 	
 	def update_effects_tree(self):
-		
+	
+		# get the selection
+		selection = self.treeEffects.get_selection()
+		(model, paths) = selection.get_selected_rows()
+		if len(paths) == 1:
+			# save the selected path for later
+			path = paths[0]
+	
 		# Populate effects tree again
 		self.OSTreeEffects.populate_tree(self.copy_of_clip.effects)
 		
 		# hide settings if no effects found
-		if not self.copy_of_clip.effects:
-			self.vbox_effect_settings.set_property('visible', False) 
-		else:
-			# select last effect
-			last_effect_index = len(self.copy_of_clip.effects) - 1
+		#if not self.copy_of_clip.effects:
+		#	self.vbox_effect_settings.set_property('visible', False) 
+		#else:
+		# select last effect
+		if len(paths) == 1:
+			# select the path that was selected before the tree was repopulated
 			selection = self.treeEffects.get_selection()
-			selection.select_path((last_effect_index,))
+			selection.select_path(path)
 			
-			# call click event for the tree
-			self.on_treeEffects_button_release_event(self.treeEffects)
+		# call click event for the tree
+		self.on_treeEffects_button_release_event(self.treeEffects)
 		
 		
 
@@ -474,6 +486,9 @@ class frmClipProperties(SimpleGtkBuilderApp):
 			# Move Effect
 			self.copy_of_clip.Move_Effect(unique_id, "up")
 			
+			# Move the selection one step up
+			self.move_tree_selection(-1)
+			
 			# clear effect controls
 			self.clear_effect_controls()
 			
@@ -490,6 +505,9 @@ class frmClipProperties(SimpleGtkBuilderApp):
 			# Move Effect
 			self.copy_of_clip.Move_Effect(unique_id, "down")
 			
+			# Move the selection one step down
+			self.move_tree_selection(1)
+			
 			# clear effect controls
 			self.clear_effect_controls()
 			
@@ -497,6 +515,34 @@ class frmClipProperties(SimpleGtkBuilderApp):
 			self.update_effects_tree()
 			
 
+	def move_tree_selection(self, number_of_rows):
+		"""
+		moves the selection in the treeview some rows, and stops at the edges
+		if the selection gets out of bounds (if sel < 0 or sel > len - 1).
+		number_of_rows: The number of rows to move (positive direction down)
+		"""
+	
+		# get the selection
+		selection = self.treeEffects.get_selection()
+		(model, paths) = selection.get_selected_rows()
+		
+		# set y to the selected row index
+		(y,) = paths[0]
+		
+		# change the value of y
+		y += number_of_rows
+		
+		# make sure it doesn't get outside bounds
+		if y < 0:
+			y = 0
+		last_effect_index = len(self.copy_of_clip.effects) - 1
+		if y > last_effect_index:
+			y = last_effect_index
+		
+		# select the new row index
+		selection.select_path((y,))
+	
+
 	def on_btnResetVolume_clicked(self, widget, *args):
 		print "on_btnResetVolume_clicked"
 		
@@ -783,6 +829,7 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		# Get settings
 		localcboEnableVideo = self.chkEnableVideo.get_active()
 		localcboEnableAudio = self.chkEnableAudio.get_active()
+		localspinbtnStart = self.spinbtnStart.get_value()
 		localtxtIn = self.txtIn.get_value()
 		localtxtOut = self.txtOut.get_value()
 		localtxtLength = float(self.txtLength.get_text().split()[0])
@@ -810,6 +857,7 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		localscaleAlpha = self.scaleAlpha.get_value()
 		
 		# update clip object
+		clip_object.position_on_track = localspinbtnStart
 		clip_object.play_video = localcboEnableVideo
 		clip_object.play_audio = localcboEnableAudio
 		clip_object.speed = localsliderSpeed	# set new speed
@@ -848,6 +896,9 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		# update keyframes
 		clip_object.keyframes = self.keyframes
 		
+		# Update the thumbnail
+		clip_object.update_thumbnail()
+		
 		if localcboDirection.lower() == _("Reverse").lower():
 			clip_object.reversed = True
 		else:
