@@ -64,7 +64,10 @@ class frmNewProject(SimpleGtkBuilderApp):
 		elif len(self.project.folder) > 0:
 			# set default folder (if there is a current folder)
 			self.fileProjectFolder.set_current_folder(self.project.folder)
-	
+			
+			
+		# init the profile
+		self.set_dropdown_values(self.form.settings.general["default_profile"], self.cmbProjectType)
 			
 		if (self.mode == "saveas"):
 			# Save project as
@@ -90,9 +93,6 @@ class frmNewProject(SimpleGtkBuilderApp):
 			
 			# init the length textbox	to 10 minutes
 			self.spinProjectLength.set_text("10")
-			
-			# init the profile
-			self.set_dropdown_values(self.form.settings.general["default_profile"], self.cmbProjectType)
 
 
 
@@ -153,7 +153,7 @@ class frmNewProject(SimpleGtkBuilderApp):
 	def on_frmNewProject_destroy(self, widget, *args):
 		print "on_frmNewProject_destroy called with self.%s" % widget.get_name()
 
-		# Is openshot existing?
+		# Is openshot exiting?
 		if self.project.form.is_exiting:
 			self.project.form.frmMain.destroy()
 			
@@ -181,10 +181,10 @@ class frmNewProject(SimpleGtkBuilderApp):
 	def on_btnCreateProject_clicked(self, widget, *args):
 		print "on_btnCreateProject_clicked called with self.%s" % widget.get_name()
 
+		extension = ".osp"
 		localName = str.strip(self.txtProjectName.get_text())
 		localFolder = str.strip(self.fileProjectFolder.get_filename())
 		localType = self.cmbProjectType.get_active_text()
-		localLength = str.strip(self.spinProjectLength.get_text())
 
 		# Validate the the form is valid
 		if (len(localName) == 0):
@@ -196,51 +196,65 @@ class frmNewProject(SimpleGtkBuilderApp):
 			messagebox.show(_("Validation Error!"), _("Please enter a valid project type."))
 
 		else:
-
+			path = os.path.join(localFolder, localName + extension)
 			
-			# check if mode is 'New Project'
-			if (self.mode == "new"):
-				# Re-init / clear the current project object (to reset all exisint data)
-				self.project = project.project()
-				self.project.form = self.form
-				self.project.form.project = self.project
-				
-				# clear history (since we are opening a new project)
-				self.project.form.history_stack = []
-				self.project.form.history_index = -1
-				self.project.form.refresh_history()
-				self.project.set_project_modified(is_modified=True, refresh_xml=False, type=_("New project"))
-			
-			# set the project properties
-			self.project.name = localName
-			self.project.project_type = localType	# set the mlt profile
-			self.project.mlt_profile = None			# clear the cached mlt_profile object
-			self.project.folder = localFolder
-			self.project.sequences[0].length = float(localLength) * 60  # convert to seconds
-			self.project.set_project_modified(is_modified=False, refresh_xml=True)
+			# Control if the file already exists
+			if os.path.exists(path):
+				# Show confirm box
+				messagebox.show(_("Confirm Overwrite"), _("There is already a project named %s%s in the selected folder. Would you like to overwrite it?") % (localName, extension), gtk.BUTTONS_YES_NO, self.create_project)
+			else:
+				self.create_project()
 
-			# stop video
-			self.project.form.MyVideo.pause()
+	def create_project(self):
+	
+		localName = str.strip(self.txtProjectName.get_text())
+		localFolder = str.strip(self.fileProjectFolder.get_filename())
+		localType = self.cmbProjectType.get_active_text()
+		localLength = str.strip(self.spinProjectLength.get_text())
+	
+		# check if mode is 'New Project'
+		if (self.mode == "new"):
+			# Re-init / clear the current project object (to reset all exisint data)
+			self.project = project.project()
+			self.project.form = self.form
+			self.project.form.project = self.project
+		
+			# clear history (since we are opening a new project)
+			self.project.form.history_stack = []
+			self.project.form.history_index = -1
+			self.project.form.refresh_history()
+			self.project.set_project_modified(is_modified=True, refresh_xml=False, type=_("New project"))
+	
+		# set the project properties
+		self.project.name = localName
+		self.project.project_type = localType	# set the mlt profile
+		self.project.mlt_profile = None			# clear the cached mlt_profile object
+		self.project.folder = localFolder
+		self.project.sequences[0].length = float(localLength) * 60  # convert to seconds
+		self.project.set_project_modified(is_modified=False, refresh_xml=True)
 
-			# set the profile settings in the video thread
-			self.project.form.MyVideo.set_project(self.project, self.project.form, os.path.join(self.project.USER_DIR, "sequence.mlt"), mode="preview")
-			self.project.form.MyVideo.set_profile(localType, load_xml=True)
+		# stop video
+		self.project.form.MyVideo.pause()
 
-			#start the autosave
-			self.project.form.setup_autosave()
+		# set the profile settings in the video thread
+		self.project.form.MyVideo.set_project(self.project, self.project.form, os.path.join(self.project.USER_DIR, "sequence.mlt"), mode="preview")
+		self.project.form.MyVideo.set_profile(localType, load_xml=True)
 
-			# Save the project
-			self.project.Save("%s/%s.osp" % (localFolder, localName))
+		#start the autosave
+		self.project.form.setup_autosave()
 
-			# Is openshot existing?
-			if self.project.form.is_exiting:
-				self.project.form.frmMain.destroy()
+		# Save the project
+		self.project.Save("%s/%s.osp" % (localFolder, localName))
 
-			# Update the main form
-			self.project.form.refresh()
+		# Is openshot existing?
+		if self.project.form.is_exiting:
+			self.project.form.frmMain.destroy()
 
-			# close the window
-			self.frmNewProject.destroy()
+		# Update the main form
+		self.project.form.refresh()
+
+		# close the window
+		self.frmNewProject.destroy()
 
 
 def main():
