@@ -30,6 +30,7 @@ import os, sys
 import subprocess
 import fnmatch
 import gtk
+
 from xml.dom import minidom
 from classes import files, messagebox, project, profiles
 from windows.SimpleGtkBuilderApp import SimpleGtkBuilderApp
@@ -41,7 +42,7 @@ from windows import fontselector
 import language.Language_Init as Language_Init
 
 
-class frmNewTitle(SimpleGtkBuilderApp):
+class frmTitles(SimpleGtkBuilderApp):
 
 	def __init__(self, path="titles.ui", root="frmTitles", domain="OpenShot", form=None, project=None, file=None, **kwargs):
 		SimpleGtkBuilderApp.__init__(self, os.path.join(project.UI_DIR, path), root, domain, **kwargs)
@@ -106,6 +107,13 @@ class frmNewTitle(SimpleGtkBuilderApp):
 		else:
 			self.filename = self.file
 			self.load_svg_template(self.file)
+			
+			try:
+				self.update_font_color_button()
+				self.update_background_color_button()
+			except:
+				print "Warning: Failed to initialize the color pickers from the SVG."
+			
 			#set edit button states
 			self.btnEditText.set_sensitive(True)
 			self.btnFont.set_sensitive(True)
@@ -113,13 +121,12 @@ class frmNewTitle(SimpleGtkBuilderApp):
 			self.btnBackgroundColor.set_sensitive(True)
 			self.btnAdvanced.set_sensitive(True)
 			self.writeToFile(self.xmldoc)
-			#show the text editor
-			#if self.noTitles == False:
-			#	self.on_btnEditText_clicked(widget)
 			#preview the file
 			self.set_img_pixbuf(self.filename)
 			
-			self.on_btnEditText_clicked(None)
+			#show the text editor
+			if self.noTitles == False:
+				self.on_btnEditText_clicked(None)
 			
 			#turn off the create button once we have created the new file
 			self.btnCreate.set_sensitive(False)
@@ -151,6 +158,10 @@ class frmNewTitle(SimpleGtkBuilderApp):
 			
 		#load the template doc to read xml
 		self.load_svg_template(self.template_name)
+		
+		self.update_font_color_button()
+		self.update_background_color_button()
+		
 		#set the new filename
 		(fileBaseName, fileExtension)=os.path.splitext(self.template_name)
 		self.filename = self.filename + fileExtension
@@ -187,31 +198,65 @@ class frmNewTitle(SimpleGtkBuilderApp):
 		self.btnCreate.set_sensitive(True)
 
 	def setTitleName(self):  
+	
+		base_name = project_path = os.path.join(self.project.folder, "thumbnail") 
+	
 		#base this on a message dialog  
-		dialog = gtk.MessageDialog(  
+		name_dialog = gtk.MessageDialog(  
 			None,  
 			gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,  
 			gtk.MESSAGE_QUESTION,  
 			gtk.BUTTONS_OK,  
-			None)  
-		dialog.set_markup(_('Please enter a name for the new Title file:'))  
+			_('Please enter a name for the new Title file.'))
+		name_dialog.set_title(_("Enter Name"))
 		#create the text input field  
 		entry = gtk.Entry()  
 		entry.set_text(_("New Title"))
 		#allow the user to press enter as well as the OK button
-		entry.connect("activate", self.ShowInputDialog, dialog, gtk.RESPONSE_OK)  
+		entry.connect("activate", self.ShowInputDialog, name_dialog, gtk.RESPONSE_OK)  
 		hbox = gtk.HBox()  
 		hbox.pack_start(gtk.Label(_("Name:")), False, 5, 5)  
 		hbox.pack_end(entry)  
 		#add it and show it  
-		dialog.vbox.pack_end(hbox, True, True, 0)  
-		dialog.show_all()  
-		#show the dialog  
-		if dialog.run() == gtk.RESPONSE_OK:
-			text = entry.get_text()
-		else: 
-			text = ''
-		dialog.destroy()
+		name_dialog.vbox.pack_end(hbox, True, True, 0)
+		name_dialog.show_all()  
+		
+		# Show the dialog until the name doesn't exist in the project or the user gives permission to overwrite
+		while True:
+			
+			# OK clicked
+			if name_dialog.run() == gtk.RESPONSE_OK:
+				text = entry.get_text()
+				# The path to the image, if created
+				path = os.path.join(base_name, text + ".svg")
+				
+				# If a file with the path already is imported to the project
+				if self.project.project_folder.file_exists_in_project(path):
+				
+					# Create an "Are you sure you  want to overwrite?" dialog
+					overwrite_dialog = gtk.MessageDialog(  
+						name_dialog,  
+						gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,  
+						gtk.MESSAGE_QUESTION,  
+						gtk.BUTTONS_YES_NO,  
+						_("An image with the name '%s' already exists in the project.\nDo you want to overwrite it?" % (text + ".svg")))
+					overwrite_dialog.set_title(_("Overwrite Image?"))
+					response = overwrite_dialog.run()
+					overwrite_dialog.destroy()
+					
+					# If the user clicked yes, stop showing the dialog
+					if response == gtk.RESPONSE_YES:
+						break
+				else:
+					# Stop looping
+					break
+			# The user clicked 'x'
+			else: 
+				text = ''
+				# Stop looping
+				break
+		
+		name_dialog.destroy()
 		return text
 
 	def ShowInputDialog(self,entry, dialog, response):  
@@ -298,6 +343,7 @@ class frmNewTitle(SimpleGtkBuilderApp):
 		
 		# refresh the main form
 		self.form.refresh_files()
+		
 
 	def find_in_list(self, l, value):
 		'''when passed a partial value, function will return the list index'''
@@ -316,16 +362,16 @@ class frmNewTitle(SimpleGtkBuilderApp):
 			s = self.rect_node[0].attributes["style"].value
 			ar = s.split(";")
 			fill = self.find_in_list(ar, "fill:")
-			if fill:
-				ar[fill] = "fill:" + color
-			else:
+			if fill == None:
 				ar.append("fill:" + color)
+			else:
+				ar[fill] = "fill:" + color
 			
 			opacity = self.find_in_list(ar, "opacity:")  
-			if opacity:
-				ar[opacity] = "opacity:" + str(self.bg_color_alpha)
-			else:
+			if opacity == None:
 				ar.append("opacity:" + str(self.bg_color_alpha))
+			else:
+				ar[opacity] = "opacity:" + str(self.bg_color_alpha)
 			
 			#rejoin the modifed parts
 			t = ";"
@@ -405,16 +451,16 @@ class frmNewTitle(SimpleGtkBuilderApp):
 			#split the text node so we can access each part
 			ar = s.split(";")
 			fill = self.find_in_list(ar, "fill:")
-			if fill:
-				ar[fill] = "fill:" + self.font_color_code
-			else:
+			if fill == None:
 				ar.append("fill:" + self.font_color_code)
+			else:
+				ar[fill] = "fill:" + self.font_color_code
 			
 			opacity = self.find_in_list(ar, "opacity:")  
-			if opacity:
-				ar[opacity] = "opacity:" + str(self.font_color_alpha)
-			else:
+			if opacity == None:
 				ar.append("opacity:" + str(self.font_color_alpha))
+			else:
+				ar[opacity] = "opacity:" + str(self.font_color_alpha)
 			
 			t = ";"
 			text_child.setAttribute("style", t.join(ar))
@@ -428,10 +474,10 @@ class frmNewTitle(SimpleGtkBuilderApp):
 				#split the text node so we can access each part
 				ar = s.split(";")
 				fill = self.find_in_list(ar, "fill:")
-				if fill:   
-					ar[fill] = "fill:" + self.font_color_code
-				else:
+				if fill == None:   
 					ar.append("fill:" + self.font_color_code)
+				else:
+					ar[fill] = "fill:" + self.font_color_code
 				t = ";"
 				tspan_child.setAttribute("style", t.join(ar))
 
@@ -480,28 +526,125 @@ class frmNewTitle(SimpleGtkBuilderApp):
 
 
 	def on_btnBackgroundColor_color_set(self, widget):
-		self.bg_color_code = self.btnBackgroundColor.get_color()
-		color_name = self.html_color(self.bg_color_code)
-		
-		# get background alpha
-		raw_alpha = float(self.btnBackgroundColor.get_alpha())
-		self.bg_color_alpha = raw_alpha / 65535.0
-		
-		#set the style element
-		self.set_bg_style(color_name)
+		try:
+			self.bg_color_code = self.btnBackgroundColor.get_color()
+			color_name = self.html_color(self.bg_color_code)
+			
+			# get background alpha
+			raw_alpha = float(self.btnBackgroundColor.get_alpha())
+			self.bg_color_alpha = raw_alpha / 65535.0
+			
+			#set the style element
+			self.set_bg_style(color_name)
+		except:
+			print "Warning: Failed to set background color."
 
 
 	def on_btnFontColor_color_set(self, widget):
-		# get font color
-		self.font_color_code = self.btnFontColor.get_color()
-		self.font_color_code = self.html_color(self.font_color_code)
-
-		# get font alpha
-		raw_alpha = float(self.btnFontColor.get_alpha())
-		self.font_color_alpha = raw_alpha / 65535.0
+		try:
+			# get font color
+			self.font_color_code = self.btnFontColor.get_color()
+			self.font_color_code = self.html_color(self.font_color_code)
+	
+			# get font alpha
+			raw_alpha = float(self.btnFontColor.get_alpha())
+			self.font_color_alpha = raw_alpha / 65535.0
+			
+			#set the style element
+			self.set_font_color()
+		except:
+			print "Warning: Failed to set font color."
 		
-		#set the style element
-		self.set_font_color()
+	def update_font_color_button(self):
+		"""Updates the color shown on the font color button"""
+	
+		# Loop through each TEXT element
+		for node in self.text_node:
+		
+			# Get the value in the style attribute
+			s = node.attributes["style"].value
+			
+			# split the node so we can access each part
+			ar = s.split(";")
+			color = self.find_in_list(ar, "fill:")
+		
+			try:
+				# Parse the result
+				txt = ar[color]
+				color = gtk.gdk.color_parse(txt[5:])
+			except:
+				# If the color was in an invalid format, try the next text element
+				continue
+			
+			opacity = self.find_in_list(ar, "opacity:")
+			
+			try:
+				# Parse the result
+				txt = ar[opacity]
+				opacity = float(txt[8:])
+			except:
+				pass
+			
+			# Default the font color to white if non-existing
+			if color == None:
+				color = gtk.gdk.color_parse("#FFFFFF")
+			
+			# Default the opacity to fully visible if non-existing
+			if opacity == None:
+				opacity = 1.0
+			
+			# Set the color value of the button
+			self.btnFontColor.set_color(color)
+			
+			# Convert the opacity into the gtk alpha value
+			alpha = int(opacity * 65535.0)
+			# Set the alpha value of the button
+			self.btnFontColor.set_alpha(alpha)
+			
+	def update_background_color_button(self):
+		"""Updates the color shown on the background color button"""
+
+		if self.rect_node:
+			
+			# All backgrounds should be the first (index 0) rect tag in the svg
+			s = self.rect_node[0].attributes["style"].value
+			
+			# split the node so we can access each part
+			ar = s.split(";")
+			
+			color = self.find_in_list(ar, "fill:")
+		
+			try:
+				# Parse the result
+				txt = ar[color]
+				color = gtk.gdk.color_parse(txt[5:])
+			except ValueError:
+				pass
+			
+			opacity = self.find_in_list(ar, "opacity:")
+			
+			try:
+				# Parse the result
+				txt = ar[opacity]
+				opacity = float(txt[8:])
+			except ValueError:
+				pass
+			
+			# Default the background color to black if non-existing
+			if color == None:
+				color = gtk.gdk.color_parse("#000000")
+			
+			# Default opacity to fully visible if non-existing
+			if opacity == None:
+				opacity = 1.0
+		
+			# Set the color value of the button
+			self.btnBackgroundColor.set_color(color)
+			
+			# Convert the opacity into the gtk alpha value
+			alpha = int(opacity * 65535.0)
+			# Set the alpha value of the button
+			self.btnBackgroundColor.set_alpha(alpha)
 
 	
 	def on_btnFont_clicked(self, widget):
@@ -563,9 +706,9 @@ class frmEditText(SimpleGtkBuilderApp):
 
 
 
-def main():
-	frm_titles = frmNewTitle()
-	frm_titles.run()
-
-if __name__ == "__main__":
-	main()
+#def main():
+#	frm_titles = frmTitles()
+#	frm_titles.run()
+#
+#if __name__ == "__main__":
+#	main()
