@@ -54,9 +54,7 @@ class OpenShotTree:
 			# icon view
 			# create a ListStore
 			self.store = gtk.ListStore(gtk.gdk.Pixbuf, str, str, str, str)
-			
-			self.treeview.set_item_width(130)
-			
+
 			self.treeview.set_pixbuf_column(0)
 			self.treeview.set_text_column(2)
 			self.treeview.set_text_column(1)
@@ -87,7 +85,7 @@ class OpenShotTree:
 		# clear the tree data
 		self.store.clear()
 
-
+		
 		# Init List of Effects
 		EFFECTS_DIR = self.project.EFFECTS_DIR
 		my_effects = []
@@ -102,13 +100,22 @@ class OpenShotTree:
 		else:	
 			my_effects = self.project.form.effect_list
 		
+		# Get icon size from settings
+		icon_size = self.project.form.settings.general["icon_size"]
+		if type(self.treeview) == gtk.IconView:
+			# only resize IconView
+			if icon_size == "small":
+				self.treeview.set_item_width(90)
+			else:
+				self.treeview.set_item_width(130)
+		
 		
 		# Add effects to dropdown
 		counter = 0
 		for my_effect in my_effects:
 
 			# get image for filter
-			file_path = os.path.join(EFFECTS_DIR, "icons", "medium", my_effect.icon)
+			file_path = os.path.join(EFFECTS_DIR, "icons", icon_size, my_effect.icon)
 			
 			# get the pixbuf
 			pbThumb = gtk.gdk.pixbuf_new_from_file(file_path)
@@ -125,6 +132,27 @@ class OpenShotTree:
 				# skip to next item in loop
 				continue
 			
+			# does the frei0r installation include this effect?
+			if my_effect.service.startswith("frei0r"):
+				if my_effect.service not in self.project.form.filters:
+					# don't add this effect, skip to the next one
+					print "Warning: effect not found in your version of Frei0r: %s" % my_effect.service
+					continue
+
+			# The way sox effects filters are indentified in MLT
+			# changed in 0.7.4. Previously, there was just a generic 'sox' filter.
+			# From 0.7.4, each sox effect is output individually.
+			# The following check will only work with versions 0.7.4 and above
+			# of MLT.
+			if self.project.form.MyVideo:
+				if self.project.form.MyVideo.check_version(0, 7, 4):
+					# does the sox installation include this effect?
+					if my_effect.service.startswith("sox"):
+						if ("sox.%s" % my_effect.audio_effect) not in self.project.form.filters:
+							# don't add this effect, skip to the next one
+							print "Warning: effect not found in your version of Sox: %s" % ("sox:%s" % my_effect.audio_effect)
+							continue
+			
 			# check if a filter matches (if any)
 			if not self.does_match_filter(my_effect, filter):
 				# NO match, so skip to next filter
@@ -276,12 +304,13 @@ class OpenShotTree:
 		
 		##Fired when the editable label cell is edited
 		#get the row that was edited
-		iter = model.get_iter_from_string(row)
-		column = cell.get_data(_("Label"))
+		#iter = model.get_iter_from_string(row)
+		#column = cell.get_data(_("Label"))
 		#set the edit in the model
-		model.set(iter,3,new_text)
+		#model.set(iter,3,new_text)
 		#update the file object with the label edit
-		filename = model.get_value(iter, 1)
-		project.project_folder.UpdateFileLabel(filename, new_text, 0)
+		#filename = model.get_value(iter, 1)
+		#project.project_folder.UpdateFileLabel(filename, new_text, 0)
+		pass
 
 
