@@ -59,6 +59,10 @@ class PreferencesMgr(SimpleGtkBuilderApp):
 		for use_stock in [_("Yes"), _("No")]:
 			self.cmbSmoothScrolling.append_text(use_stock)
 			
+		# populate icon size options
+		for icon_size in [_("Small"), _("Medium")]:
+			self.cmbIconSize.append_text(icon_size)
+			
 		# disable scrolling options (based on MLT version)
 		if self.form.MyVideo:
 			if self.form.MyVideo.check_version(0, 6, 0):
@@ -95,18 +99,27 @@ class PreferencesMgr(SimpleGtkBuilderApp):
 		self.set_dropdown_values(theme_name, self.cmbThemes)
 		self.set_dropdown_values(self.form.settings.general["output_mode"], self.cmbOutputModes)
 		
+		# Init stock dropdown
 		use_stock_icons = self.form.settings.general["use_stock_icons"]
 		if use_stock_icons == "Yes":
 			self.set_dropdown_values(_("Yes"), self.cmbUseStockIcons)
 		else:
 			self.set_dropdown_values(_("No"), self.cmbUseStockIcons)
-			
+		
+		# Init smooth scrolling dropdown
 		use_affine = self.form.settings.general["use_affine"]
 		if use_affine == "Yes":
 			self.set_dropdown_values(_("Yes"), self.cmbSmoothScrolling)
 		else:
 			self.set_dropdown_values(_("No"), self.cmbSmoothScrolling)
 		
+		# Init icon size dropdown
+		icon_size = self.form.settings.general["icon_size"]
+		if icon_size == "small":
+			self.set_dropdown_values(_("Small"), self.cmbIconSize)
+		else:
+			self.set_dropdown_values(_("Medium"), self.cmbIconSize)
+		
 		#autosave objects
 		if self.form.settings.general["autosave_enabled"] == "True":
 			self.chkEnableAutosave.set_active(True)
@@ -144,7 +157,7 @@ class PreferencesMgr(SimpleGtkBuilderApp):
 		# re-select default profile
 		self.set_default_profile(self.form.settings.general["default_profile"])
 		if not self.cmbProfiles.get_active_text():
-			self.set_default_profile("DV NTSC")
+			self.set_default_profile("DV/DVD NTSC")
 			
 		
 	def populate_codecs(self):
@@ -179,9 +192,11 @@ class PreferencesMgr(SimpleGtkBuilderApp):
 		
 		melt_command = self.form.settings.general["melt_command"]
 		self.form.get_avformats(melt_command)
-		
+
 		self.populate_codecs()
 		
+
+		
 		
 	def on_btnClose_clicked(self, widget, *args):
 		#write the values from the form to the dictionary objects
@@ -238,6 +253,20 @@ class PreferencesMgr(SimpleGtkBuilderApp):
 			self.form.settings.general["use_affine"] = "Yes"
 		else:
 			self.form.settings.general["use_affine"] = "No"
+			
+	def on_cmbIconSize_changed(self, widget, *args):
+		
+		_ = self._
+		icon_size = self.cmbIconSize.get_active_text()
+		
+		if icon_size == _("Small"):
+			self.form.settings.general["icon_size"] = "small"
+		else:
+			self.form.settings.general["icon_size"] = "medium"
+			
+		# refresh effects and transitions
+		self.form.on_btnTransFilterAll_toggled(widget)
+		self.form.on_btnAllEffects_toggled(widget)
 
 
 	def on_cmbThemes_changed(self, widget, *args):
@@ -325,8 +354,8 @@ class Settings:
 	#values will be overwritten with the file values.
 	general = {
 		"imported_image_length" : "7",
-		"default_theme" : "fresh",
-		"default_profile" : "DV NTSC",
+		"default_theme" : "fresher",
+		"default_profile" : "DV/DVD NTSC",
 		"project_file_type" : "ascii",
 		"max_history_size" : "20",
 		"melt_command" : "melt",
@@ -337,6 +366,7 @@ class Settings:
 		"save_interval" : 1,
 		"autosave_enabled" : False,
 		"save_before_playback" : False,
+		"icon_size" : "medium",
 		}
 	
 	app_state = {
@@ -400,6 +430,13 @@ class Settings:
 							if os.path.exists(os.path.join(self.project.THEMES_DIR, section_dict[key])) == False:
 								# DOES NOT EXIST, change to default
 								section_dict[key] = "blue_glass"
+								
+						# be sure profile exists
+						if key == "default_profile":
+							if profiles.mlt_profiles(self.project).profile_exists(section_dict[key]) == False:
+								# DOES NOT EXIST, change to default
+								print "Default profile does not exist: %s. Changing default profile to %s." % (section_dict[key], "DV/DVD NTSC")
+								section_dict[key] = "DV/DVD NTSC"
 						
 					except IndexError:
 						#the list index will go out of range if there is
